UAInspector v0.11.1 UAInspector.Database behaviour
Basic database module providing minimal functions.
Summary
Callbacks
Returns all database entries as a list
Returns the database sources
Starts the short code map server
Converts a raw entry to its ets representation
Callbacks
Specs
to_ets(entry :: any, type :: String.t) :: term
Converts a raw entry to its ets representation.
If necessary a data conversion is made from the raw data passed directly out of the database file and the actual data needed when querying the database.